@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 import sys
 from functools import wraps
+import six
 from funcy import cached_property, project, once, once_per, monkey
 from funcy.py2 import cat, mapcat, map
 from .cross import pickle, json, md5
@@ -135,7 +136,7 @@ def _stringify_query():
     # Try to not require geo libs
     try:
         from django.contrib.gis.db.models.sql.where import GeoWhereNode
-    except ImportError:
+    except: # either ImportError or GEOSException
         GeoWhereNode = WhereNode
 
     # A new things in Django 1.6
@@ -277,9 +278,9 @@ class QuerySetMixin(object):
 
         return 'q:%s' % md.hexdigest()
 
-    def _cache_results(self, cache_key, results, timeout=None):
+    def _cache_results(self, cache_key, results):
         cond_dnfs = dnfs(self)
-        cache_thing(cache_key, results, cond_dnfs, timeout or self._cacheconf['timeout'])
+        cache_thing(cache_key, results, cond_dnfs, self._cacheconf['timeout'])
 
     def cache(self, ops=None, timeout=None, write_only=None):
         """
@@ -536,7 +537,7 @@ def invalidate_m2m(sender=None, instance=None, model=None, action=None, pk_set=N
     if not sender._meta.auto_created:
         return
 
-    m2m = next(m2m for m2m in instance._meta.many_to_many
+    m2m = next(m2m for m2m in instance._meta.many_to_many + model._meta.many_to_many
                    if m2m.rel.through == sender)
 
     # TODO: optimize several invalidate_objs/dicts at once
@@ -591,3 +592,9 @@ def install_cacheops():
 
     # bind m2m changed handler
     m2m_changed.connect(invalidate_m2m)
+
+    # Make buffers pickleable
+    if six.PY2:
+        import copy_reg
+        copy_reg.pickle(buffer, lambda b: (buffer, (bytes(b),)))
+
